======================
django-stripe-payments
======================

a payments Django app for Stripe

This app allows you to process one off charges as well as signup users for
recurring subscriptions managed by Stripe.
